document.addEventListener('plusready', orderListInit, false);

function orderListInit() {
	$('.order-tab-item').on('click', function() {
		var local_state = $(this).attr('data-state');
		localStorage.setItem('local_state', local_state);
		clicked('my_order_list.html');
	});

	$('.order-list').on('click', '.order-item', function(e) {
		var order_item_id = $(e.currentTarget).attr('data-order-id');
		localStorage.setItem('order_item_id', order_item_id);
		clicked('order_detail.html');
	});
	
	$('.btn-refresh').on('click', function(e){
		renderOrderList();
	});

	renderOrderList();
}

function renderOrderList() {
	GetOrderItems('history');
}

function GetOrderItems(state) {
	// 获取服务工单
	var app_id = localStorage.getItem('app_id');
	var app_key = localStorage.getItem('app_key');
	var user_data = {
		'app_id': app_id,
		'app_key': app_key
	};
	var post_data = {
		params: {
			'user': user_data,
			'page_num': 0,
			'state': state
		}
	};
	plus.nativeUI.showWaiting();
	$.ajax({
		url: GET_ORDER_SERVICE,
		dataType: 'json',
		type: 'POST',
		contentType: 'application/json',
		data: JSON.stringify(post_data),
		success: function(retData) {
			plus.nativeUI.closeWaiting();
			//console.log(JSON.stringify(retData));
			if(retData.error != undefined) {
				toast('服务出错，请重试!');
			} else {
				var result = retData.result;
				var data = result.data.order_list;
				var new_count = result.data.new_count;
				var progressing_count = result.data.progressing_count;
				if(result.status == 'success') {
					$('.order-list').html('<div class="order-title">最近工单</div>');
					$.each(data, function(idx, item) {
						var state_name = '';
						var state_class = '';
						if(item.state == 'distributed') {
							state_name = '未接单';
							state_class = 'order-item-state-distributed';
						} else if(item.state == 'done') {
							state_name = '完成';
							state_class = 'order-item-state-done';
						} else if(item.state == 'accepted') {
							state_name = '已接单';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'remote-processing') {
							state_name = '远程处理中';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'processing') {
							state_name = '上门处理中';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'go') {
							state_name = '出发';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'start') {
							state_name = '开工';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'confirm-done') {
							state_name = '等待后台确认';
							state_class = 'order-item-state-progressing';
						} else if(item.state == 'rejected') {
							state_name = '已拒绝';
							state_class = 'order-item-state-rejected';
						} else if(item.state == 'return') {
							state_name = '返单';
							state_class = 'order-item-state-return';
						} else {
							state_name = '进行中';
							state_class = 'order-item-state-progressing';
						}

						var html_order_item = template('tmpl_order_item', {
							'state_name': state_name,
							'state_class': state_class,
							'item': item
						});
						$('.order-list').append(html_order_item);

						if(new_count > 0) {
							$('.new-badge').show();
							$('.new-badge').html(new_count);
						} else {
							$('.new-badge').hide();
						}

						if(progressing_count > 0) {
							$('.processing-badge').show();
							$('.processing-badge').html(progressing_count);
						} else {
							$('.processing-badge').hide();
						}
					});

					if(data.length < 1) {
						$('.no-order-list').show();
					} else {
						$('.no-order-list').hide();
					}
				} else if(result.status == 'fail') {
					toast(result.message);
				} else if(result.status == 'out_time') {
					plus.nativeUI.alert(result.message, function(e) {
						back();
					}, '确定');

				}
			}
		},
		error: function(retData) {
			plus.nativeUI.closeWaiting();
		},
		complete: function(c) {
			plus.nativeUI.closeWaiting();
		}
	});
}